EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DockerImages_UpdateDescription',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates the short or full description of a Docker repository.'
GO

IF OBJECT_ID('[DockerImages_UpdateDescription]') IS NOT NULL DROP PROCEDURE [DockerImages_UpdateDescription]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [DockerImages_UpdateDescription]
(
	@Feed_Id INT,
	@Repository_Name VARCHAR(255),
	@ShortDescription_Text NVARCHAR(100) = NULL,
	@FullDescription_Text NVARCHAR(MAX) = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT * FROM [DockerRepositoryDescriptions] WHERE [Feed_Id] = @Feed_Id AND [Repository_Name] = @Repository_Name)

		UPDATE [DockerRepositoryDescriptions]
		   SET [ShortDescription_Text] = NULLIF(COALESCE(@ShortDescription_Text, [ShortDescription_Text]), ''),
		       [FullDescription_Text] = NULLIF(COALESCE(@FullDescription_Text, [FullDescription_Text]), '')
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Repository_Name] = @Repository_Name

	ELSE

		INSERT INTO [DockerRepositoryDescriptions]
		(
			[Feed_Id],
			[Repository_Name],
			[ShortDescription_Text],
			[FullDescription_Text]
		)
		VALUES
		(
			@Feed_Id,
			@Repository_Name,
			NULLIF(@ShortDescription_Text, ''),
			NULLIF(@FullDescription_Text, '')
		)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DockerImages_UpdateDescription] TO [ProGetUser_Role]
GO