EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Security_CreateOrUpdateRole',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Role_Id',
    /* Description_Text        */ 'Creates or updates a role.'
GO

IF OBJECT_ID('[Security_CreateOrUpdateRole]') IS NOT NULL DROP PROCEDURE [Security_CreateOrUpdateRole]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Security_CreateOrUpdateRole]
(
	@Role_Id INT = NULL OUT,
	@Role_Name NVARCHAR(50),
    @Role_Description VARCHAR(MAX),
	@Tasks_Csv VARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    DECLARE @FeedScopable_Indicator YNINDICATOR
            SET @FeedScopable_Indicator = CASE
                WHEN EXISTS (SELECT * FROM [Tasks] 
                              WHERE [Feed_Scopeable_Indicator] = 'N'
                               AND [Task_Id] IN (SELECT [Value_Text] FROM [CsvToTable](@Tasks_Csv, ',')))
                     THEN 'N' ELSE 'Y' END


	IF @Role_Id IS NULL
	BEGIN

		INSERT INTO [Roles]
		(
			[Role_Name],
            [Role_Description],
            [FeedScopable_Indicator]
		)
		VALUES
		(
			@Role_Name,
            @Role_Description,
            @FeedScopable_Indicator
		)

		SET @Role_Id = SCOPE_IDENTITY()

		EXEC [Events_RaiseEvent] 'SECNWR', NULL, 'Role_Id', @Role_Id, 'Role_Name', @Role_Name

	END
	ELSE
	BEGIN

		UPDATE [Roles]
		   SET [Role_Name] = @Role_Name,
               [Role_Description] = @Role_Description,
               [FeedScopable_Indicator] = @FeedScopable_Indicator
		 WHERE [Role_Id] = @Role_Id

		DELETE [RoleTasks]
		 WHERE [Role_Id] = @Role_Id

		EXEC [Events_RaiseEvent] 'SECMDR', NULL, 'Role_Id', @Role_Id, 'Role_Name', @Role_Name
	END

	INSERT INTO [RoleTasks]
	(
		[Role_Id],
		[Task_Id]
	)
	SELECT @Role_Id,
	       [Value_Text]
	  FROM dbo.CsvToTable(@Tasks_Csv, ',')

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Security_CreateOrUpdateRole] TO [ProGetUser_Role]
GO
